aboutsummaryrefslogtreecommitdiff
path: root/plat/qemu/common/qemu_stack_protector.c
diff options
context:
space:
mode:
Diffstat (limited to 'plat/qemu/common/qemu_stack_protector.c')
-rw-r--r--plat/qemu/common/qemu_stack_protector.c14
1 files changed, 10 insertions, 4 deletions
diff --git a/plat/qemu/common/qemu_stack_protector.c b/plat/qemu/common/qemu_stack_protector.c
index c226158ad6..d0b4a0f1d3 100644
--- a/plat/qemu/common/qemu_stack_protector.c
+++ b/plat/qemu/common/qemu_stack_protector.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2018, ARM Limited and Contributors. All rights reserved.
+ * Copyright (c) 2021, ARM Limited and Contributors. All rights reserved.
*
* SPDX-License-Identifier: BSD-3-Clause
*/
@@ -7,17 +7,23 @@
#include <stdint.h>
#include <arch_helpers.h>
+#include <arch_features.h>
#include <plat/common/platform.h>
#define RANDOM_CANARY_VALUE ((u_register_t) 3288484550995823360ULL)
u_register_t plat_get_stack_protector_canary(void)
{
+ /* Use the RNDR instruction if the CPU supports it */
+ if (is_feat_rng_supported()) {
+ return read_rndr();
+ }
+
/*
* Ideally, a random number should be returned instead of the
* combination of a timer's value and a compile-time constant.
- * As the virt platform does not have any random number generator,
- * this is better than nothing but not necessarily really secure.
+ * This is better than nothing but not necessarily really secure.
*/
return RANDOM_CANARY_VALUE ^ read_cntpct_el0();
}
@@ -7,17 +7,23 @@
/*
- * Ideally, a random number should be returned instead of the
+ * Ideally, a random number should be returned above. If a random
+ * number generator is not supported, return instead a
* combination of a timer's value and a compile-time constant.